@@ -4,8 +4,12 @@ our $VERSION = 0.01;
 
 our @INC = ('Exception::Base');
 
-sub broken_method {
-    my $self = 
-}
+BEGIN {
+    eval q{
+        sub broken_method {
+            my $self =
+        };
+    };
+};
 
 1;
